Re-exports
pub use bobcat_host as host;
Macros
- read_
args_ safe - read_
words - revert_
if_ bad_ call_ slice_ vec - Reverts with a message if the revertdata is Some, and if the rc is false.
- revert_
if_ bad_ call_ unit_ vec - Reverts if the underlying call failed, using the vector that was returned as the third argument as slice.
- revert_
if_ bad_ call_ vec - Like write_result_exit_call, except it only reverts with the returndata if the underlying call reverted. If it doesn’t, then it just returns the slice.
- write_
result_ exit_ call - write_
result_ exit_ create - write_
result_ exit_ res
Structs
Functions
- balance
- block_
basefee - block_
timestamp - chain_
id - code_
hash - code_
size - code_
slice - code_
vec - code_
vec_ size - contract_
address - evm_
gas_ left - evm_
ink_ left - exit_
early ⚠ - leftpad_
addr - msg_
sender - msg_
value - read_
args - Read arguments from the Stylus VM (calldata), using unsafe MaybeUninit code if we’re on the wasm host. If we’re on a non wasm host, zero it out then return it. We also return the length.
- read_
args_ vec - return_
data_ size - storage_
flush_ ⚠cache - write_
result_ arr - Write a result array, avoiding a copy.
- write_
result_ bool - write_
result_ slice - Write a result slice.
- write_
result_ word